@@ -156,7 +156,7 @@ example administration repository rules and an admin user and group.
    ERROR_GROUP_LOOP = "Loop detected involving: ${path}",
    ERROR_DUPLICATE_KEYRING = "Duplicate keyring name: ${name}",
    ERROR_KEYRING_NOT_BLOB = "${path}.gpg is not a blob?",
-   ERROR_NO_BYPASS_USER = "User 'gitano-bypass' not found",
+   ERROR_NO_BYPASS_USER_FOUND = "User 'gitano-bypass' not found",
    ERROR_BYPASS_USER_IN_GROUP = "User 'gitano-bypass' is in group '${group}' which makes no sense",
    ERROR_BYPASS_USER_LACKING = "User 'gitano-bypass' has no SSH keys and does not have an HTTP password set",
    ERROR_GENERIC_CONF_NOT_FOUND = "Not found: ${sha}::${name}",
@@ -194,8 +194,6 @@ example administration repository rules and an admin user and group.
    WARN_MARKDOWN_ERROR = "<${name}> Markdown: ${reason}",
    ERROR_REALISE_NON_NASCENT = "Cannot realise a non-nascent repository",
    ERROR_CANNOT_PREP_PATH = "Cannot prepare path leading to repository",
-   MSG_CHANGING_README = "Changing README",
-   MSG_CHANGED_README = "<${name}> Changed README",
    MSG_CHANGING_HEAD = "Changing project HEAD",
    MSG_CHANGED_HEAD = "<${name}> Set head to <${head}>",
    DEBUG_CALCULATE_TOKEN = "Calculating confirmation token for ${name}",
@@ -230,7 +228,7 @@ example administration repository rules and an admin user and group.
    DEBUG_WELCOME_TO = "Welcome to ${site}",
    DEBUG_RUNNING = "Running:",
    DEBUG_ON_BEHALF_OF = "On behalf of ${user} using key ${key}",
-   ERROR_RUNNING_COMMAND = "Error running ${cmd}: ${reason}",
+   ERROR_RUNNING_COMMAND = "Error running ${cmd}: ${reason} ${code}",
    UNABLE_TO_CONTINUE = "Unable to continue",
    MSG_COMPLETED_SUCCESSFULLY = "${cmd} completed successfully",
    WARN_UNTERMINATED_STRING = "Un-terminated quoted string",
