@@ -12,7 +12,6 @@ local log = require 'gitano.log'
 local command = require 'gitano.command'
 local actions = require 'gitano.actions'
 local lace = require 'gitano.lace'
-local markdown = require 'gitano.markdown'
 local supple = require 'gitano.supple'
 local auth = require 'gitano.auth'
 local plugins = require 'gitano.plugins'
@@ -26,7 +25,6 @@ return {
    command = command,
    actions = actions,
    lace = lace,
-   markdown = markdown,
    supple = supple,
    auth = auth,
    plugins = plugins,
