@@ -24,9 +24,9 @@ local lib_bin_path = "/tmp/DOES_NOT_EXIST"
 local share_path = "/tmp/DOES_NOT_EXIST"
 local repo_path = "/tmp/DOES_NOT_EXIST"
 
-local admin_name = { 
-   realname = "Gitano", 
-   email = "gitano@gitano-admin.git" 
+local admin_name = {
+   realname = "Gitano",
+   email = "gitano@gitano-admin.git"
 }
 
 local required_confs = {
@@ -65,7 +65,7 @@ local function parse_admin_config(commit)
 
    local conf, err =
       clod.parse(flat_tree["site.conf"].obj.content,
-		   "gitano-admin:" .. commit.sha .. ":site.conf")
+                 "gitano-admin:" .. commit.sha .. ":site.conf")
 
    if not conf then
       return nil, err
@@ -75,8 +75,8 @@ local function parse_admin_config(commit)
 
    for k, t in pairs(required_confs) do
       if type(conf.settings[k]) ~= t then
-	 return nil, i18n.expand("ERROR_SITE_CONF_TYPE",
-				 {sha=commit.sha, key=k, want=t, got=type(conf.settings[k])})
+         return nil, i18n.expand("ERROR_SITE_CONF_TYPE",
+                                 {sha=commit.sha, key=k, want=t, got=type(conf.settings[k])})
       end
    end
 
@@ -94,7 +94,7 @@ local function parse_admin_config(commit)
 
          -- Found a user, fill them out
          local user_clod, err = clod.parse(obj.obj.content,
-            commit.sha .. ":" .. prefix .. username .. "/user.conf")
+                                           commit.sha .. ":" .. prefix .. username .. "/user.conf")
 
          if not user_clod then
             return nil, err
@@ -111,14 +111,14 @@ local function parse_admin_config(commit)
          end
 
          users[username] = setmetatable({ clod = user_clod, keys = {},
-            meta = { prefix = prefix }, }, user_mt)
+                                          meta = { prefix = prefix }, }, user_mt)
       end
    end
 
    -- Now gather the users' keys
    local all_keys = {}
    for filename, obj in pairs(flat_tree) do
-      local prefix, username, keyname = filename:match("^(users/.-)([a-z][a-z0-9_.-]+)/([a-z][a-z0-9_-.]+)%.key$")
+      local prefix, username, keyname = filename:match("^(users/.-)([a-z][a-z0-9_.-]+)/([a-z][a-z0-9_.-]+)%.key$")
       if prefix and username and keyname then
          if not users[username] then
             return nil, i18n.expand("ERROR_ORPHAN_KEY",
@@ -139,17 +139,17 @@ local function parse_admin_config(commit)
          if (keytype ~= "ssh-rsa") and (keytype ~= "ssh-dss") and
             (keytype ~= "ecdsa-sha2-nistp256") and
             (keytype ~= "ecdsa-sha2-nistp384") and
-            (keytype ~= "ecdsa-sha2-nistp521") then
+         (keytype ~= "ecdsa-sha2-nistp521") then
             return nil, i18n.expand("ERROR_BAD_KEY_TYPE",
                                     {keytype=keytype, filename=filename})
          end
 
          if all_keys[this_key] then
-	    return nil, i18n.expand(
-	       "ERROR_DUPLICATE_KEY",
-	       {keyname=keyname, username=username,
-		otherkey=all_keys[this_key].keyname,
-		otheruser=all_keys[this_key].username})
+            return nil, i18n.expand(
+               "ERROR_DUPLICATE_KEY",
+               {keyname=keyname, username=username,
+                otherkey=all_keys[this_key].keyname,
+                otheruser=all_keys[this_key].username})
          end
          all_keys[this_key] = { keyname = keyname, username = username }
          users[username].keys[keyname] = {
@@ -166,76 +166,76 @@ local function parse_admin_config(commit)
    for filename, obj in pairs(flat_tree) do
       local prefix, groupname = filename:match("^(groups/.-)([a-z][a-z0-9_.-]+)%.conf$")
       if prefix and groupname then
-	 if groups[groupname] then
-	    return nil, i18n.expand("ERROR_DUPLICATE_GROUP", {name=groupname})
-	 end
-	 if not is_blob(obj) then
-	    return nil, i18n.expand("ERROR_GROUP_NOT_BLOB", {path=prefix..groupname})
-	 end
-	 local group_clod, err =
-	    clod.parse(obj.obj.content,
-		       "gitano-admin:" .. commit.sha .. ":" .. 
-			  prefix .. groupname .. ".conf", true)
+         if groups[groupname] then
+            return nil, i18n.expand("ERROR_DUPLICATE_GROUP", {name=groupname})
+         end
+         if not is_blob(obj) then
+            return nil, i18n.expand("ERROR_GROUP_NOT_BLOB", {path=prefix..groupname})
+         end
+         local group_clod, err =
+            clod.parse(obj.obj.content,
+                       "gitano-admin:" .. commit.sha .. ":" ..
+                          prefix .. groupname .. ".conf", true)
 
-	 if not group_clod then
-	    return nil, err
-	 end
-	 if type(group_clod.settings.description) ~= "string" then
-	    return nil, i18n.expand("ERROR_GROUP_NO_DESCRIPTION", {name=groupname})
-	 end
-	 local group_globals = {
-	    clod = group_clod,
-	    settings = group_clod.settings,
-	    members = {},
-	    subgroups = {},
-	 }
-	 for i, member in ipairs(group_clod:get_list("members")) do
-	    group_globals.members[i] = member
-	    group_globals.members[member] = i
-	 end
-	 for i, subgroup in ipairs(group_clod:get_list("subgroups")) do
-	    group_globals.subgroups[i] = subgroup
-	    group_globals.subgroups[subgroup] = i
-	 end
-	 function group_globals.changed_tables()
-	    group_globals.clod:set_list("members", group_globals.members)
-	    group_globals.clod:set_list("subgroups", group_globals.subgroups)
-	 end
-	 groups[groupname] = group_globals
-	 groups[groupname].meta = { prefix = prefix }
+         if not group_clod then
+            return nil, err
+         end
+         if type(group_clod.settings.description) ~= "string" then
+            return nil, i18n.expand("ERROR_GROUP_NO_DESCRIPTION", {name=groupname})
+         end
+         local group_globals = {
+            clod = group_clod,
+            settings = group_clod.settings,
+            members = {},
+            subgroups = {},
+         }
+         for i, member in ipairs(group_clod:get_list("members")) do
+            group_globals.members[i] = member
+            group_globals.members[member] = i
+         end
+         for i, subgroup in ipairs(group_clod:get_list("subgroups")) do
+            group_globals.subgroups[i] = subgroup
+            group_globals.subgroups[subgroup] = i
+         end
+         function group_globals.changed_tables()
+            group_globals.clod:set_list("members", group_globals.members)
+            group_globals.clod:set_list("subgroups", group_globals.subgroups)
+         end
+         groups[groupname] = group_globals
+         groups[groupname].meta = { prefix = prefix }
       end
-   end   
+   end
 
    -- Attempt a clean flattening of each group to ensure no loops
    for gname, gtab in pairs(groups) do
       local all_members = {}
       local all_subgroups = {}
-      local function add_group(grname, grtab, path) 
-	 if not grtab then
-	    log.fatal(i18n.expand("ERROR_GROUP_NOT_FOUND", {name=grname, path=path}))
-	    return
-	 end
-	 if all_subgroups[grname] then
-	    return nil, i18n.expand("ERROR_GROUP_LOOP", {path=path})
-	 end
-	 for _, un in ipairs(grtab.members) do
-	    if users[un] then
-	       all_members[un] = path
-	    end
-	 end
-	 all_subgroups[grname] = true
-	 for _, gn in ipairs(grtab.subgroups) do
-	    local ok, msg = add_group(gn, groups[gn], path .. "!" .. gn)
-	    if not ok then
-	       return nil, msg
-	    end
-	 end
-	 all_subgroups[grname] = false
-	 return true
+      local function add_group(grname, grtab, path)
+         if not grtab then
+            log.fatal(i18n.expand("ERROR_GROUP_NOT_FOUND", {name=grname, path=path}))
+            return
+         end
+         if all_subgroups[grname] then
+            return nil, i18n.expand("ERROR_GROUP_LOOP", {path=path})
+         end
+         for _, un in ipairs(grtab.members) do
+            if users[un] then
+               all_members[un] = path
+            end
+         end
+         all_subgroups[grname] = true
+         for _, gn in ipairs(grtab.subgroups) do
+            local ok, msg = add_group(gn, groups[gn], path .. "!" .. gn)
+            if not ok then
+               return nil, msg
+            end
+         end
+         all_subgroups[grname] = false
+         return true
       end
       local ok, msg = add_group(gname, gtab, gname)
       if not ok then
-	 return nil, msg
+         return nil, msg
       end
       gtab.filtered_members = all_members
    end
@@ -245,16 +245,16 @@ local function parse_admin_config(commit)
    for filename, obj in pairs(flat_tree) do
       local prefix, keyringname = filename:match("^(keyrings/.-)([a-z][a-z0-9_.-]+)%.gpg$")
       if prefix and keyringname then
-	 if keyrings[keyringname] then
-	    return nil, i18n.expand("ERROR_DUPLICATE_KEYRING", {name=keyringname})
-	 end
-	 if not is_blob(obj) then
-	    return nil, i18n.expand("ERROR_KEYRING_NOT_BLOB", {path=prefix .. groupname})
-	 end
-	 keyrings[keyringname] = {
-	    meta = { prefix = prefix },
-	    blob = obj.obj
-	 }
+         if keyrings[keyringname] then
+            return nil, i18n.expand("ERROR_DUPLICATE_KEYRING", {name=keyringname})
+         end
+         if not is_blob(obj) then
+            return nil, i18n.expand("ERROR_KEYRING_NOT_BLOB", {path=prefix .. groupname})
+         end
+         keyrings[keyringname] = {
+            meta = { prefix = prefix },
+            blob = obj.obj
+         }
       end
    end
 
@@ -262,13 +262,13 @@ local function parse_admin_config(commit)
    -- and (c) has at least one key and/or a password set
    if users["gitano-bypass"] then
       for gname, gtab in pairs(groups) do
-	 if gtab.filtered_members["gitano-bypass"] then
-	    return nil, i18n.expand("ERROR_BYPASS_USER_IN_GROUP", {group=gname})
-	 end
+         if gtab.filtered_members["gitano-bypass"] then
+            return nil, i18n.expand("ERROR_BYPASS_USER_IN_GROUP", {group=gname})
+         end
       end
       local okay = next(users["gitano-bypass"].keys) or users["gitano-bypass"].clod["passwd.hash"]
       if not okay then
-	 return nil, i18n.expand("ERROR_BYPASS_USER_LACKING")
+         return nil, i18n.expand("ERROR_BYPASS_USER_LACKING")
       end
    else
       return nil, i18n.expand("ERROR_NO_BYPASS_USER_FOUND")
@@ -319,7 +319,7 @@ end
 
 local function has_global_hook(conf, hook)
    return (conf.content["global-hooks/" .. hook .. ".lua"] ~= nil and
-	   conf.content["global-hooks/" .. hook .. ".lua"].type == "blob")
+              conf.content["global-hooks/" .. hook .. ".lua"].type == "blob")
 end
 
 local function get_default_hook_content(conf, filename)
@@ -332,10 +332,10 @@ local function generate_ssh_config(conf)
    local ret = {"","### Gitano Keys ###"}
    for u, t in pairs(conf.users) do
       for ktag, keytab in pairs(t.keys) do
-	 log.debug(i18n.expand("DEBUG_ADDING_SSH_KEY", {user=u, key=ktag}))
-	 ret[#ret+1] = 
-	    (('command="%s/gitano-auth \\"%s\\" \\"%s\\" \\"%s\\"",no-agent-forwarding,no-port-forwarding,no-pty,no-user-rc,no-X11-forwarding %s'):
-	     format(lib_bin_path, repo_path, u, ktag, keytab.data))
+         log.debug(i18n.expand("DEBUG_ADDING_SSH_KEY", {user=u, key=ktag}))
+         ret[#ret+1] =
+            (('command="%s/gitano-auth \\"%s\\" \\"%s\\" \\"%s\\"",no-agent-forwarding,no-port-forwarding,no-pty,no-user-rc,no-X11-forwarding %s'):
+                  format(lib_bin_path, repo_path, u, ktag, keytab.data))
       end
    end
    ret[#ret+1] = "### End Gitano Keys ###"
@@ -350,7 +350,7 @@ local function update_ssh_keys(conf, ssh_path)
       local home = luxio.getenv "HOME"
 
       if not home then
-	 log.fatal(i18n.expand("ERROR_CANNOT_FIND_HOME"))
+         log.fatal(i18n.expand("ERROR_CANNOT_FIND_HOME"))
       end
 
       ssh_path = home .. "/.ssh/authorized_keys"
@@ -383,10 +383,10 @@ local function populate_context(conf, ctx, username)
    local grps = {}
    for grp, gtab in pairs(conf.groups) do
       if gtab.filtered_members[username] then
-	 -- Array for pattern matches
-	 grps[#grps+1] = grp
-	 -- Set for exact matches
-	 grps[grp] = true
+         -- Array for pattern matches
+         grps[#grps+1] = grp
+         -- Set for exact matches
+         grps[grp] = true
       end
    end
    ctx.group = grps
@@ -415,7 +415,7 @@ local function commit_config_changes(conf, desc, author, committer)
    -- Shallow copy the tree ready for mods, skipping keyrings, users and groups
    for k,v in pairs(conf.content) do
       if not (k:match("^users/") or
-              k:match("^groups/") or
+                 k:match("^groups/") or
               k:match("^keyrings/")) then
          newtree[k] = v
       end
@@ -455,23 +455,23 @@ local function commit_config_changes(conf, desc, author, committer)
    end
 
    author = (author and {
-		realname = conf.users[author].real_name,
-		email = conf.users[author].email_address
-	    }) or admin_name
+                realname = conf.users[author].real_name,
+                email = conf.users[author].email_address
+            }) or admin_name
 
    committer = (committer and {
-		   realname = conf.users[committer].real_name,
-		   email = conf.users[committer].email_address
-	       }) or author
+                   realname = conf.users[committer].real_name,
+                   email = conf.users[committer].email_address
+               }) or author
 
-   local commit, msg = 
+   local commit, msg =
       gall.commit.create(conf.repo.git, {
-			   author = author,
-			   committer = committer,
-			   message = desc or "Updated",
-			   tree = tree,
-			   parents = { conf.commit }
-			})
+                            author = author,
+                            committer = committer,
+                            message = desc or "Updated",
+                            tree = tree,
+                            parents = { conf.commit }
+      })
    if not commit then
       return nil, msg
    end
@@ -483,9 +483,9 @@ local function commit_config_changes(conf, desc, author, committer)
    end
 
    -- Create/Update the HEAD ref
-   local ok, msg = conf.repo.git:update_ref(conf.repo.git.HEAD, 
-					    commit.sha, nil,
-					    conf.commit.sha)
+   local ok, msg = conf.repo.git:update_ref(conf.repo.git.HEAD,
+                                            commit.sha, nil,
+                                            conf.commit.sha)
    if not ok then
       return nil, msg
    end
