@@ -24,23 +24,23 @@ local function _loader(ctx, _name)
    if not global_name then
       -- Project load
       if ctx.project and not ctx.project_tree then
-	 ctx.project_tree = gall.tree.flatten(ctx.project.content.tree.content)
+         ctx.project_tree = gall.tree.flatten(ctx.project.content.tree.content)
       end
       if ctx.project_tree then
-	 tree = ctx.project_tree
-	 sha = ctx.project.sha
+         tree = ctx.project_tree
+         sha = ctx.project.sha
       end
    else
       -- Global load
       if global_lookaside[global_name] then
-	 local resolved = global_lookaside[global_name]
-	 if type(resolved) == "function" then
-	    resolved = resolved(ctx)
-	 end
-	 return "global_lookaside::" .. global_name, resolved
+         local resolved = global_lookaside[global_name]
+         if type(resolved) == "function" then
+            resolved = resolved(ctx)
+         end
+         return "global_lookaside::" .. global_name, resolved
       end
       if not ctx.global_tree then
-	 ctx.global_tree = gall.tree.flatten(ctx.global.content.tree.content)
+         ctx.global_tree = gall.tree.flatten(ctx.global.content.tree.content)
       end
       tree = ctx.global_tree
       sha = ctx.global.sha
@@ -53,7 +53,7 @@ local function _loader(ctx, _name)
    local real_name = sha .. "::" .. blob_name
    if not tree[blob_name] or tree[blob_name].type ~= "blob" then
       local m = i18n.expand("ERROR_UNABLE_TO_FIND_RULE",
-			    { name=blob_name, sha=sha, inname=_name })
+                            { name=blob_name, sha=sha, inname=_name })
       log.ddebug(m)
       return lace.error.error(m)
    end
@@ -62,20 +62,20 @@ end
 
 local match_types = {
    exact = function(want, have)
-	      return want == have
-	   end,
+      return want == have
+   end,
    prefix = function(want, have)
-	       return have:sub(1, #want) == want
-	    end,
+      return have:sub(1, #want) == want
+   end,
    suffix = function(want, have)
-	       return have:sub(-#want) == want
-	    end,
+      return have:sub(-#want) == want
+   end,
    pattern = function(want, have)
-		return (have:match(want) ~= nil)
-	     end,
+      return (have:match(want) ~= nil)
+   end,
    pcre = function(want, have)
-	     return (pcre.match(have, want) ~= nil)
-	  end
+      return (pcre.match(have, want) ~= nil)
+   end
 }
 
 -- Match aliases (auto-inverted)
@@ -96,9 +96,6 @@ do
    end
 end
 
--- Match aliases (not auto-inverted)
-match_types["not"] = match_types["!is"]
-
 local function _do_simple_match(ctx, key, matchtype, value)
    value = util.process_expansion(ctx, value)
    local kk = ctx[key] or ""
@@ -113,10 +110,10 @@ local function _do_simple_match(ctx, key, matchtype, value)
    else
       local ret = false
       for k in pairs(kk) do
-	 ret = ret or check(value, k)
+         ret = ret or check(value, k)
       end
       if matchtype:sub(1,1) == "!" then
-	 ret = not ret
+         ret = not ret
       end
       return ret
    end
@@ -181,8 +178,8 @@ local base_compcontext = {
 local function cloddly_bless(ctx)
    local function indexer(tab, name)
       if name:sub(1,7) == "config/" then
-	 tab[name] = _simple_match
-	 return _simple_match
+         tab[name] = _simple_match
+         return _simple_match
       end
    end
    setmetatable(ctx._lace.controltype, {__index = indexer})
@@ -198,9 +195,9 @@ local function compile_ruleset(repo, adminsha, globaladminsha)
    compcontext.repo = repo
    if not repo.is_nascent then
       if not adminsha then
-	 compcontext.project = repo.git:get("refs/gitano/admin")
+         compcontext.project = repo.git:get("refs/gitano/admin")
       else
-	 compcontext.project = repo.git:get(adminsha)
+         compcontext.project = repo.git:get(adminsha)
       end
    end
    if not globaladminsha then
