@@ -14,7 +14,6 @@ local config = require 'gitano.config'
 local util = require 'gitano.util'
 local lace = require 'gitano.lace'
 local i18n = require 'gitano.i18n'
-local markdown = require 'gitano.markdown'
 local clod = require 'clod'
 
 local base_rules = [[
@@ -27,9 +26,9 @@ project.description ""
 project.owner "gitano/nobody"
 ]]
 
-local admin_name = { 
-   realname = "Gitano", 
-   email = "gitano@gitano-admin.git" 
+local admin_name = {
+   realname = "Gitano",
+   email = "gitano@gitano-admin.git"
 }
 
 local adminrefname = "refs/gitano/admin"
@@ -43,11 +42,11 @@ function repo_method:load_from_admin_ref(filename)
    local entry = flat_tree[filename]
    if not entry then
       return nil, i18n.expand("ERROR_GENERIC_CONF_NOT_FOUND",
-			      {sha=admincommit.sha, name=filename})
+                              {sha=admincommit.sha, name=filename})
    end
    if entry.obj.type ~= "blob" then
       return nil, i18n.expand("ERROR_GENERIC_CONF_NOT_BLOB",
-			      {sha=admincommit.sha, name=filename})
+                              {sha=admincommit.sha, name=filename})
    end
    return entry.obj.content, admincommit.sha .. "::" .. filename
 end
@@ -73,7 +72,7 @@ end
 
 function repo_method:fs_path()
    return ("%s/%s.git"):format(config.repo_path(),
-			       self.name)
+                               self.name)
 end
 
 function repo_method:run_checks()
@@ -86,41 +85,41 @@ function repo_method:run_checks()
       -- First, the blob for the rules
       local rules, msg = gall.object.create(self.git, "blob", base_rules)
       if not rules then
-	 return nil, msg
+         return nil, msg
       end
       local conf, msg = gall.object.create(self.git, "blob", base_config)
       if not conf then
-	 return nil, msg
+         return nil, msg
       end
       -- Next the tree containing the blob
-      local flat_tree = { 
-	 ["rules/main.lace"] = rules,
-	 ["project.conf"] = conf,
+      local flat_tree = {
+         ["rules/main.lace"] = rules,
+         ["project.conf"] = conf,
       }
       local tree, msg = gall.tree.create(self.git, flat_tree)
       if not tree then
-	 return nil, msg
+         return nil, msg
       end
       -- Now a commit of the blob, using the gitano admin identity
-      local commit, msg = 
-	 gall.commit.create(self.git, {
-			      author = admin_name,
-			      committer = admin_name,
-			      message = i18n.expand("INITIAL_ADMIN_TREE"),
-			      tree = tree
-			   })
+      local commit, msg =
+         gall.commit.create(self.git, {
+                               author = admin_name,
+                               committer = admin_name,
+                               message = i18n.expand("INITIAL_ADMIN_TREE"),
+                               tree = tree
+         })
       if not commit then
-	 return nil, msg
+         return nil, msg
       end
       -- Finally create/update the gitano/admin ref
       local ok, msg = self.git:update_ref(adminrefname, commit.sha)
       if not ok then
-	 return nil, msg
+         return nil, msg
       end
    end
 
    -- Admin tree exists, validate and load it...
-   local ok, tab = 
+   local ok, tab =
       self:validate_admin_sha(self.git:get_ref(adminrefname))
    if not ok then
       return nil, tab
@@ -150,7 +149,7 @@ function repo_method:run_checks()
    if not ok then
       return nil, msg
    end
-   
+
    -- And all is well
    return true
 end
@@ -188,9 +187,9 @@ function repo_method:check_signature(obj, keyringname)
    while w < #b do
       _b, err = sfd:write(b, w)
       if _b == nil or _b < 1 then
-	 -- I know we're not handling EINTR/EAGAIN, I don't care
-	 w = -1
-	 break
+         -- I know we're not handling EINTR/EAGAIN, I don't care
+         w = -1
+         break
       end
       w = w + _b
    end
@@ -229,9 +228,9 @@ function repo_method:check_local_git_files()
       local fh, errmsg = sio.open(self:fs_path() .. "/git-daemon-export-ok", "wc")
 
       if fh then
-        fh:close()
+         fh:close()
       else
-        log.warn(i18n.expand("ERROR_CANNOT_CREATE_EXPORT_FILE", {reason=errmsg}))
+         log.warn(i18n.expand("ERROR_CANNOT_CREATE_EXPORT_FILE", {reason=errmsg}))
       end
    else
       luxio.unlink(self:fs_path() .. "/git-daemon-export-ok")
@@ -243,34 +242,14 @@ function repo_method:check_local_git_files()
       fh:write("\n")
       fh:close()
       local ok, errno = luxio.rename(self:fs_path() .. ("/description.%d.new"):format(luxio.getpid()),
-				     self:fs_path() .. "/description")
+                                     self:fs_path() .. "/description")
       if ok ~= 0 then
-	 log.warn(i18n.expand("ERROR_UNABLE_TO_RENAME_INTO_PLACE",
-			      {what="description", reason=luxio.strerror(errno)}))
+         log.warn(i18n.expand("ERROR_UNABLE_TO_RENAME_INTO_PLACE",
+                              {what="description", reason=luxio.strerror(errno)}))
       end
    else
       log.warn(i18n.expand("ERROR_UNABLE_TO_WRITE_FILE",
-			   {what="description", reason=tostring(err)}))
-   end
-   -- And now our readme if we have one
-   if self.readme_html then
-      local fh, err = sio.open(self:fs_path() .. ("/README.html.%d.new"):format(luxio.getpid()), "wc")
-      if fh then
-	 fh:write(self.readme_html)
-	 fh:close()
-	 local ok, errno = luxio.rename(self:fs_path() .. ("/README.html.%d.new"):format(luxio.getpid()),
-					self:fs_path() .. "/README.html")
-	 if ok ~= 0 then
-	    log.warn(i18n.expand("ERROR_UNABLE_TO_RENAME_INTO_PLACE",
-			      {what="README.html", reason=luxio.strerror(errno)}))
-	 end
-      else
-	 log.warn(i18n.expand("ERROR_UNABLE_TO_WRITE_FILE",
-			      {what="README.html", reason=tostring(err)}))
-      end
-   else
-      -- Remove any readme (and ignore errors)
-      luxio.unlink(self:fs_path() .. "/README.html")
+                           {what="description", reason=tostring(err)}))
    end
    -- Check that our HEAD is correctly configured
    local our_head = self:conf_get "project.head"
@@ -282,7 +261,7 @@ function repo_method:check_local_git_files()
    local owner = self.config.users[self:conf_get "project.owner"]
    if owner then
       self.git:config("gitweb.owner",
-		      owner.real_name .. " <" .. owner.email_address .. ">")
+                      owner.real_name .. " <" .. owner.email_address .. ">")
    end
    -- Construct a cgitrc in case we're using cgit instead of gitweb
    local cgitrc = {}
@@ -294,7 +273,10 @@ function repo_method:check_local_git_files()
       "snapshots" } do
       local v = self.project_config.settings["cgitrc." .. suffix]
       if v then
-	 add_cgitrc(suffix, v)
+         if v == "readme" and not v:find(":") then
+            v = ":" .. v
+         end
+         add_cgitrc(suffix, v)
       end
    end
    if owner then
@@ -316,14 +298,14 @@ function repo_method:check_local_git_files()
       fh:write(cgitrc)
       fh:close()
       local ok, errno = luxio.rename(self:fs_path() .. ("/cgitrc.%d.new"):format(luxio.getpid()),
-				     self:fs_path() .. "/cgitrc")
+                                     self:fs_path() .. "/cgitrc")
       if ok ~= 0 then
-	 log.warn(i18n.expand("ERROR_UNABLE_TO_RENAME_INTO_PLACE",
-			      {what="cgitrc", reason=luxio.strerror(errno)}))
+         log.warn(i18n.expand("ERROR_UNABLE_TO_RENAME_INTO_PLACE",
+                              {what="cgitrc", reason=luxio.strerror(errno)}))
       end
    else
       log.warn(i18n.expand("ERROR_UNABLE_TO_WRITE_FILE",
-			   {what="cgitrc", reason=tostring(err)}))
+                           {what="cgitrc", reason=tostring(err)}))
    end
 
    return true
@@ -334,19 +316,19 @@ function repo_method:check_and_upgrade_hooks()
    for _, hook in ipairs {"pre-receive", "update", "post-receive"} do
       local hookfile = ("%s/hooks/%s"):format(self:fs_path(), hook)
       local hooktarget = ("%s/gitano-%s-hook"):format(config.lib_bin_path(),
-						      hook)
+                                                      hook)
       local ok, linkv = luxio.readlink(hookfile)
       local redo = false
       if ok > 0 then
-	 if linkv ~= hooktarget then
-	    redo = true
-	 end
+         if linkv ~= hooktarget then
+            redo = true
+         end
       else
-	 redo = true
+         redo = true
       end
       if redo then
-	 luxio.unlink(hookfile)
-	 luxio.symlink(hooktarget, hookfile)
+         luxio.unlink(hookfile)
+         luxio.symlink(hooktarget, hookfile)
       end
    end
    return true
@@ -369,8 +351,8 @@ function repo_method:validate_admin_sha(sha)
 
    local conf_text = tree["project.conf"].obj.content
    local conf, err = clod.parse(conf_text,
-			       self.name .. ":" .. 
-				  sha .. ":project.conf")
+                                self.name .. ":" ..
+                                   sha .. ":project.conf")
    if not conf then
       return nil, err
    end
@@ -383,7 +365,7 @@ function repo_method:validate_admin_sha(sha)
       conf.settings["owner"] = nil
    end
    if conf.settings["description"] and
-      not conf.settings["project.description"] then
+   not conf.settings["project.description"] then
       conf.settings["project.description"] = conf.settings["description"]
       conf.settings["description"] = nil
    end
@@ -404,21 +386,9 @@ function repo_method:validate_admin_sha(sha)
       conf.settings["project.head"] = "refs/heads/master"
    end
 
-   if is_blob(tree["README.mdwn"]) then
-      local mdwn_src = tree["README.mdwn"].obj.content
-      local ok, res = pcall(markdown.convert_to_html, mdwn_src)
-      if ok then
-	 ret.readme_html = res
-	 ret.readme_mdwn = mdwn_src
-      else
-	 log.warn(i18n.expand("WARN_MARKDOWN_ERROR", {name=self.name,
-						      reason=res}))
-      end
-   end
-
    -- Generate a Lace for the project at this ref
    local lace, msg = lace.compile(self, sha)
-   if not lace then 
+   if not lace then
       return nil, msg
    end
    -- And store it for use later
@@ -429,24 +399,24 @@ end
 
 function repo_method:populate_context(context)
    util.add_splitable(context, "repository", self.name,
-		      "/", "dirname", "basename")
+                      "/", "dirname", "basename")
    context["_repo"] = self
    if not self.is_nascent then
       local lists_to_add = {}
       for k, v in self.project_config:each() do
-	 if k:match("%.i_[0-9]+$") then
-	    lists_to_add[k:gsub("%.i_[0-9]+$", "")] = true
-	 else
-	    local confkey = "config/" .. k:gsub("%.", "/")
-	    context[confkey] = v
-	 end
+         if k:match("%.i_[0-9]+$") then
+            lists_to_add[k:gsub("%.i_[0-9]+$", "")] = true
+         else
+            local confkey = "config/" .. k:gsub("%.", "/")
+            context[confkey] = v
+         end
       end
       for k in pairs(lists_to_add) do
-	 local confkey = "config/" .. k:gsub("%.", "/")
-	 local vallist = self.project_config:get_list(k)
-	 local valset = {}
-	 for _, v in pairs(vallist) do valset[v] = true end
-	 context[confkey] = valset
+         local confkey = "config/" .. k:gsub("%.", "/")
+         local vallist = self.project_config:get_list(k)
+         local valset = {}
+         for _, v in pairs(vallist) do valset[v] = true end
+         context[confkey] = valset
       end
    end
 end
@@ -455,7 +425,7 @@ function repo_method:realise()
    if not self.is_nascent then
       return false, i18n.expand("ERROR_REALISE_NON_NASCENT")
    end
-   
+
    if not util.mkdir_p(util.dirname(self:fs_path())) then
       return false, i18n.expand("ERROR_CANNOT_PREP_PATH")
    end
@@ -476,7 +446,7 @@ function repo_method:conf_set_and_save(conf, newvalue, author, committer)
    local oldvalue = self:conf_get(conf)
    self:conf_set(conf, newvalue)
    local ok, msg = self:save_admin("Setting " .. conf .. " to " .. newvalue,
-				   author, committer)
+                                   author, committer)
    if not ok then
       self:conf_set(conf, oldvalue)
       return nil, msg
@@ -485,19 +455,6 @@ function repo_method:conf_set_and_save(conf, newvalue, author, committer)
    return true
 end
 
-function repo_method:set_readme(newreadme, author, committer)
-   local oldreadme = self.readme_mdwn
-   self.readme_mdwn = newreadme
-   local ok, msg = self:save_admin(i18n.expand("MSG_CHANGING_README"),
-				   author, committer)
-   if not ok then
-      self.readme_mdwn = oldreadme
-      return nil, msg
-   end
-   log.state(i18n.expand("MSG_CHANGED_README", {name=self.name}))
-   return true
-end
-
 function repo_method:set_head(newhead, author, committer)
    if not newhead:match("^refs/") then
       newhead = "refs/heads/" .. newhead
@@ -505,7 +462,7 @@ function repo_method:set_head(newhead, author, committer)
    local oldhead = self:conf_get "project.head"
    self:conf_set("project.head", newhead)
    local ok, msg = self:save_admin(i18n.expand("MSG_CHANGING_HEAD"),
-				   author, committer)
+                                   author, committer)
    if not ok then
       self:conf_set("project.head", oldhead)
       return nil, msg
@@ -564,7 +521,7 @@ function repo_method:rename_to(somename)
    somename = somename:gsub("%.", "")
    -- Remove any leading or trailing /
    somename = somename:match("^/*(.-)/*$")
-   
+
    local newpath = self.fs_path({name=somename,config=self.config})
 
    if not util.mkdir_p(util.dirname(newpath)) then
@@ -599,22 +556,22 @@ function repo_method:copy_to(target)
    ok, err = luxio.mkdir(temp_path, sio.tomode'0755')
    if ok ~= 0 then
       log.error(i18n.expand("ERROR_FAILED_TO_COPY",
-			    {path=self:fs_path(),
-			     newpath=newpath,
-			     reason=i18n.expand("ERROR_COPY_IN_PROGRESS")}))
+                            {path=self:fs_path(),
+                             newpath=newpath,
+                             reason=i18n.expand("ERROR_COPY_IN_PROGRESS")}))
       return false, i18n.expand("ERROR_COPY_IN_PROGRESS")
    end
 
    local from = self:fs_path()
    local function filter(parent, name, info)
       return parent == from and name == "objects"
-             or util.copy_dir_filter_base(parent, name, info)
+         or util.copy_dir_filter_base(parent, name, info)
    end
    -- copy non-objects parts of the git repository
    ok, err = util.copy_dir(from, temp_path, nil, filter)
    if not ok then
       log.error(i18n.expand("ERROR_FAILED_TO_COPY",
-			    {path=from, newpath=temp_path, reason=err}))
+                            {path=from, newpath=temp_path, reason=err}))
       util.rm_rf(temp_path)
       return false, i18n.expand("ERROR_FAILED_COPYING_CONTENT")
    end
@@ -626,7 +583,7 @@ function repo_method:copy_to(target)
                            cbs)
    if not ok then
       log.error(i18n.expand("ERROR_FAILED_HARDLINKING",
-			    {path=from, newpath=temp_path, reason=err}))
+                            {path=from, newpath=temp_path, reason=err}))
       util.rm_rf(temp_path)
       return ok, i18n.expand("ERROR_FAILED_COPYING_CONTENT")
    end
@@ -635,8 +592,8 @@ function repo_method:copy_to(target)
    ok, err = luxio.rename(temp_path, newpath)
    if ok ~= 0 then
       log.error(i18n.expand("ERROR_FAILED_RENAME_REPOSITORY",
-			    {from=temp_path, to=newpath,
-			     reason=luxio.strerr(err)}))
+                            {from=temp_path, to=newpath,
+                             reason=luxio.strerr(err)}))
       util.rm_rf(temp_path)
       return false, i18n.expand("ERROR_FAILED_COPYING_CONTENT")
    end
@@ -658,18 +615,18 @@ function repo_method:update_modified_date(shas)
    local function update_based_on(mtime, offset)
       mtime = tonumber(mtime)
       if mtime > last_mod_mtime then
-	 last_mod_mtime = mtime
-	 last_mod_offset = offset
+         last_mod_mtime = mtime
+         last_mod_offset = offset
       end
    end
    local f = io.open(modfile, "r")
    if f then
       local s = f:read("*l")
       if s then
-	 local cur_mod_time, cur_mod_offset = s:find("^([0-9]+) ([+-][0-9]+)$")
-	 if cur_mod_time then
-	    update_based_on(cur_mod_time, cur_mod_offset)
-	 end
+         local cur_mod_time, cur_mod_offset = s:find("^([0-9]+) ([+-][0-9]+)$")
+         if cur_mod_time then
+            update_based_on(cur_mod_time, cur_mod_offset)
+         end
       end
       f:close()
    end
@@ -678,11 +635,11 @@ function repo_method:update_modified_date(shas)
          local obj = self.git:get(sha)
          if obj.type == "tag" then
             local tagger = obj.content.tagger
-	    update_based_on(tagger.unixtime, tagger.timezone)
+            update_based_on(tagger.unixtime, tagger.timezone)
          elseif obj.type == "commit" then
-	    local committer, author = obj.content.committer, obj.content.author
-	    update_based_on(committer.unixtime, committer.timezone)
-	    update_based_on(author.unixtime, author.timezone)
+            local committer, author = obj.content.committer, obj.content.author
+            update_based_on(committer.unixtime, committer.timezone)
+            update_based_on(author.unixtime, author.timezone)
          end
       end
    end
@@ -708,35 +665,27 @@ function repo_method:save_admin(reason, author, committer)
 
    flat_tree["project.conf"] = conf_blob
 
-   if self.readme_mdwn then
-      local readme_blob, msg = gall.object.create(self.git, "blob", self.readme_mdwn)
-      if not readme_blob then
-	 return nil, msg
-      end
-      flat_tree["README.mdwn"] = readme_blob
-   end
-
    local tree, msg = gall.tree.create(self.git, flat_tree)
    if not tree then
       return nil, msg
    end
    author = (author and {
-		realname = self.config.users[author].real_name,
-		email = self.config.users[author].email_address
-	    }) or admin_name
+                realname = self.config.users[author].real_name,
+                email = self.config.users[author].email_address
+            }) or admin_name
    committer = (committer and {
-		   realname = self.config.users[committer].real_name,
-		   email = self.config.users[committer].email_address
-	       }) or author
+                   realname = self.config.users[committer].real_name,
+                   email = self.config.users[committer].email_address
+               }) or author
    -- Now a commit of the blob, using the gitano admin identity
-   local commit, msg = 
+   local commit, msg =
       gall.commit.create(self.git, {
-			   author = author,
-			   committer = committer,
-			   message = reason or i18n.expand("MSG_UPDATED_ADMIN_TREE"),
-			   tree = tree,
-			   parents = { curcommit }
-			})
+                            author = author,
+                            committer = committer,
+                            message = reason or i18n.expand("MSG_UPDATED_ADMIN_TREE"),
+                            tree = tree,
+                            parents = { curcommit }
+      })
    if not commit then
       return nil, msg
    end
@@ -747,11 +696,11 @@ function repo_method:save_admin(reason, author, committer)
    end
    -- Finally create/update the gitano/admin ref
    local ok, msg = self.git:update_ref(adminrefname, commit.sha, nil,
-				       curcommit.sha)
+                                       curcommit.sha)
    if not ok then
       return nil, msg
    end
-   
+
    return self:run_checks()
 end
 
@@ -788,30 +737,30 @@ local function check_repodir(dirname, repo)
 
    if not dirp then
       if err == luxio.ENOENT then
-	 repo.is_nascent = true
-	 return repo
+         repo.is_nascent = true
+         return repo
       else
-	 return nil, luxio.strerror(err)
+         return nil, luxio.strerror(err)
       end
    else
       local needed = {
-	 branches = true,
-	 config = true,
-	 description = true,
-	 HEAD = true,
-	 objects = true,
-	 hooks = true,
-	 refs = true
+         branches = true,
+         config = true,
+         description = true,
+         HEAD = true,
+         objects = true,
+         hooks = true,
+         refs = true
       }
       local e, i
       repeat
-	 e, i = luxio.readdir(dirp)
-	 if e == 0 then
-	    needed[i.d_name] = nil
-	 end
+         e, i = luxio.readdir(dirp)
+         if e == 0 then
+            needed[i.d_name] = nil
+         end
       until not e
       if next(needed) then
-	 return nil, i18n.expand("ERROR_SOMETHING_MISSING", {what=next(needed)})
+         return nil, i18n.expand("ERROR_SOMETHING_MISSING", {what=next(needed)})
       end
    end
 
@@ -854,7 +803,7 @@ local function find_repository(config, reponame)
       -- Load a system lace.
       local lace, reason = lace.compile(repo)
       if not lace then
-	 return nil, reason
+         return nil, reason
       end
       -- Stuff in the lace so :run_lace() work
       repo.lace = lace
@@ -885,39 +834,39 @@ local function foreach_repository(conf, callback, filterfn)
    -- "find" it and call the callback with the name, repo and message
 
    local all_repos = {}
- 
+
    local function scan_dir(dirname, prefix)
       local dirp, err = luxio.opendir(dirname)
       if not dirp then
-	 if err == luxio.ENOTDIR then
-	    return true
-	 end
-	 return nil, luxio.strerror(err)
+         if err == luxio.ENOTDIR then
+            return true
+         end
+         return nil, luxio.strerror(err)
       end
       local e, i
       local recurse = {}
       repeat
-	 e, i = luxio.readdir(dirp)
-	 if e == 0 then
-	    if i.d_name:find("%.git$") then
-	       -- Might be a repo, save for later
-	       all_repos[#all_repos+1] = (util.path_join(prefix, i.d_name)
-                                          ):gsub("^/", "")
-	    else
-	       if i.d_name:find("^[^%.]") then
-		  recurse[#recurse+1] = i.d_name
-	       end
-	    end
-	 end
+         e, i = luxio.readdir(dirp)
+         if e == 0 then
+            if i.d_name:find("%.git$") then
+               -- Might be a repo, save for later
+               all_repos[#all_repos+1] = (util.path_join(prefix, i.d_name)
+                                         ):gsub("^/", "")
+            else
+               if i.d_name:find("^[^%.]") then
+                  recurse[#recurse+1] = i.d_name
+               end
+            end
+         end
       until not e
       dirp = nil  -- Allow GC of DIR handle
       -- Now try and recurse if possible,
       for i = 1, #recurse do
-	 local ok, msg = scan_dir(util.path_join(dirname, recurse[i]),
-				  util.path_join(prefix, recurse[i]))
-	 if not ok then
-	    return ok, msg
-	 end
+         local ok, msg = scan_dir(util.path_join(dirname, recurse[i]),
+                                  util.path_join(prefix, recurse[i]))
+         if not ok then
+            return ok, msg
+         end
       end
       return true
    end
@@ -932,11 +881,11 @@ local function foreach_repository(conf, callback, filterfn)
    for i = 1, #all_repos do
       local want = true
       if filterfn and not filterfn(all_repos[i]) then
-	 want = false
+         want = false
       end
       if want then
-	 local ok, msg = find_repository(conf, all_repos[i])
-	 callback(all_repos[i], ok, msg)
+         local ok, msg = find_repository(conf, all_repos[i])
+         callback(all_repos[i], ok, msg)
       end
    end
 
